@@ -58,29 +58,31 @@ namespace Kwave
 	              sample_index_t length);
 
 	/** virtual destructor */
-	virtual ~UndoSelection();
+        virtual ~UndoSelection() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::description() */
-	QString description() Q_DECL_OVERRIDE;
+        virtual QString description() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undoSize() */
-	qint64 undoSize() Q_DECL_OVERRIDE;
+        virtual qint64 undoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::redoSize() */
-	qint64 redoSize() Q_DECL_OVERRIDE;
+        virtual qint64 redoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::store() */
-	bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
+        virtual bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undo() */
-	Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+        virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
 	                                bool with_redo) Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::containsModification() */
-	bool containsModification() const Q_DECL_OVERRIDE { return false; }
+        virtual bool containsModification() const Q_DECL_OVERRIDE {
+            return false;
+        }
 
 	/** dump, for debugging purposes */
-	void dump(const QString &indent) Q_DECL_OVERRIDE;
+        virtual void dump(const QString &indent) Q_DECL_OVERRIDE;
 
     private:
 
